@@ -189,11 +189,11 @@ def alist_batch_download(
         1) 如果为 False，则无文件会被下载
         2) 如果为 None，则全部文件都会被下载
         3) 如果为 Callable，则调用以筛选
-        4) 如果为 Container，则用扩展名（要用小写字母，带前缀点，例如 .mkv）判断，不在此中的都被过滤
+        4) 如果为 Container，则用扩展名（要用小写字母，带前缀句点，例如 .mkv）判断，不在此中的都被过滤
     :param strm_predicate: 断言以筛选，选择某些文件生成为 strm（优先级高于 predicate）
         1) 如果为 None，则无 strm
         2) 如果为 Callable，则调用以筛选
-        3) 如果为 Container，则用扩展名（要用小写字母，带前缀点，例如 .mkv）判断，不在此中的都被过滤
+        3) 如果为 Container，则用扩展名（要用小写字母，带前缀句点，例如 .mkv）判断，不在此中的都被过滤
     :param custom_url: 生成文件的 url，默认为 None，表示使用 alist 提供的 url
     :param password: `remote_dir` 的访问密码
     :param refresh: 是否刷新目录，刷新会更新 alist 上相应目录的缓存
